%% Import and Plot OpenSim .sto data
% John Rogers
%

%%
clear; clc; close all
%% Matlab Plot Parameters
figHeight = 1000; % change this value to change fig size
figWidth = 4/3*figHeight; % pixels (resulting figure('OuterPosition', rect) will be somewhat smaller)
rect = [5 50 figWidth figHeight];
myFontSize = 36;
myxTicks = [0 0.2 0.4 0.6];
myLineWidth = 5;
myMarkerSize = 20;
numPoints = 200;
%% Load Basic Model Info
load('jointFullNames_v3_Dorn.mat')
% cd  to the location of your openSim output e.g cd Run7ms\RRA etc

%% Import Force or Other Data
%powerData = importdata('subject17_Run_50001_cycle1_Actuation_power.sto');
forceData = importdata('JA1_rra_Actuation_force.sto');
dataSize = size(forceData.data);% 
timeForce = forceData.data(:, 1); % time is the first column

%%
tStart = timeForce(1); 
tEnd = timeForce(end); %  [s]
time = linspace(tStart, tEnd, numPoints);
force_u = forceData.data;% num rows x 38
% interpolate :
force = interp1(force_u(:,1), force_u(:,1:end), linspace(tStart, tEnd, numPoints));
forceNames = forceData.colheaders;

%%
% 'hip_flexion_r_reserve' is column 8
% 'knee_angle_r_reserve' is column 11
% 'ankle_angle_r_reserve' is column 12
leftLegJointIndex =[8 11 12];
leftLegForce = force(:,leftLegJointIndex);

%%
for jointNum = leftLegJointIndex % All joints: for jointNum = 2:dataSize(2)
    figure('OuterPosition', rect); hold on    
    line([tStart, tEnd],[0, 0], 'color', 'black', 'LineWidth', myLineWidth)
    plot(time, force(:,jointNum),'LineWidth', myLineWidth)
    title (jointName(jointNum),'FontSize', myFontSize)
    xlabel ('Gait Percent','FontSize', myFontSize)
    ylabel ('Joint Moment [Nm]','FontSize', myFontSize)
    axis('tight')
    H = gca;
    set(H,'FontSize', myFontSize);%, 'XTick', myxTicks)
    set(H,'FontSize', myFontSize);%, 'YTick', myyTicks)
    grid on
end

%% save  spreadsheet or .mat data:
% myOutFileName = 'jointForceSubjectJA1';
% xlswrite(myOutFileName,{'Subject JA1, running 9.5 m/s'})
% %xlswrite(myOutFileName, forceNames, 1, 'A2')% variable names, no spaces
% xlswrite(myOutFileName, jointName', 1, 'A2')
% xlswrite(myOutFileName, {'s', 'Nm or N'}, 1, 'A3')
% xlswrite(myOutFileName, force, 1, 'A4')

% save('RRAforce7mps', 'GP', 'leftLegForce')% save('RRAforce9mps'... etc